@@ -9,15 +9,14 @@
 #include <syslog.h>
 
 /*
- * An unprivileged dummy user to run as. The user and its UID must not be
- * used for any other purpose (that is, don't use "nobody" here). You can
- * #undef this to let scanlogd run as root, but I recommend against doing
- * so.
+ * An unprivileged dummy user to run as.  The user and its UID must not be
+ * used for any other purpose (that is, don't use "nobody" here).  You can
+ * #undef this to let scanlogd run as root, but this is not recommended.
  */
 #define SCANLOGD_USER			"scanlogd"
 
 /*
- * An empty directory to chroot to. The directory and its parent directories
+ * An empty directory to chroot to.  The directory and its parent directories
  * must not be writable by anyone but root.
  */
 #define SCANLOGD_CHROOT			"/var/empty"
@@ -57,19 +56,20 @@
 
 /*
  * Port scan detection thresholds: at least COUNT ports need to be scanned
- * from the same source, with no longer than DELAY ticks between ports.
+ * from the same source, with no longer than DELAY seconds between ports.
  */
 #define SCAN_MIN_COUNT			7
 #define SCAN_MAX_COUNT			(SCAN_MIN_COUNT * PORT_WEIGHT_PRIV)
 #define SCAN_WEIGHT_THRESHOLD		SCAN_MAX_COUNT
-#define SCAN_DELAY_THRESHOLD		(CLK_TCK * 3)
+#define SCAN_DELAY_THRESHOLD		3
 
 /*
  * Log flood detection thresholds: temporarily stop logging if more than
- * COUNT port scans are detected with no longer than DELAY between them.
+ * COUNT port scans are detected with no longer than DELAY seconds between
+ * them.
  */
 #define LOG_COUNT_THRESHOLD		5
-#define LOG_DELAY_THRESHOLD		(CLK_TCK * 20)
+#define LOG_DELAY_THRESHOLD		20
 
 /*
  * Log line length limit, such as to fit into one SMS message. #undef this
